[![pypi](https://img.shields.io/pypi/v/aportalsmp.svg)](https://pypi.org/project/aportalsmp/) [![stars](https://img.shields.io/github/stars/bleach-hub/aportalsmp?style=social)](https://github.com/bleach-hub/aportalsmp/stargazers) [![Me](https://img.shields.io/badge/Telegram-@perfectlystill-blue?logo=telegram)](https://t.me/perfectlystill) [![Updates & Devs chat](https://img.shields.io/badge/Telegram-@giftsdevs-blue?logo=telegram)](https://t.me/giftsdevs)

# Asynchronous Portals Marketplace API

This is an asynchronous version of my previous library - [portalsmp](https://pypi.org/project/portalsmp/)

*[Join our devs chat!](t.me/giftsdevschat)*

#### Installation

`pip install aportalsmp`

## Change log

#### Version 1.1

- First release of the library

#### Version 1.2.1

- Added functions for interacting with giveaways; added transfering & withdrawing gifts and more!

## Documentation

You can find detailed documentation & what's changed here -> [https://bleach-1.gitbook.io/aportalsmp](https://bleach-1.gitbook.io/aportalsmp)

---

## Info

*my github: [https://github.com/bleach-hub](https://github.com/bleach-hub)*

*my telegram: [https://t.me/perfectlystill](https://t.me/perfectlystill)*

*telegram channel: [https://t.me/giftsdevs](https://t.me/giftsdevs)*

*telegram chat: [https://t.me/giftsdevschat](https://t.me/giftsdevschat)*

*donations:*

- ton: `UQC9f1mTuu2hKuBP_0soC5RVkq2mLp8uiPBBhn69vadU7h8W`
- trc20: `TBeQFv8n598e3EDw4hp3YK4YQ2UwyY7Lzx`

---

*made with ❤️ by bleach*
